Class: Simplify::CardToken
- Inherits:
-
Hash
- Object
- Hash
- Simplify::CardToken
- Defined in:
- lib/simplify/cardtoken.rb
Overview
A CardToken object.
Instance Attribute Summary collapse
-
#authentication ⇒ Object
Authentication object used to access the API (See Simplify::Authentication for details).
Class Method Summary collapse
-
.create(parms, *auth) ⇒ Object
Creates an CardToken object.
-
.find(id, *auth) ⇒ Object
Retrieve a CardToken object from the API.
Instance Method Summary collapse
-
#private_key ⇒ Object
Returns the private key used when accessing this object.
-
#private_key=(k) ⇒ Object
Sets the private key used when accessing this object.
-
#public_key ⇒ Object
Returns the public key used when accessing this object.
-
#public_key=(k) ⇒ Object
Sets the public key used when accessing this object.
-
#update ⇒ Object
-
device => ipAddressThe IP address of the device used by the payer, in nnn.nnn.nnn.nnn format.
-
Instance Attribute Details
#authentication ⇒ Object
Authentication object used to access the API (See Simplify::Authentication for details)
37 38 39 |
# File 'lib/simplify/cardtoken.rb', line 37 def authentication @authentication end |
Class Method Details
.create(parms, *auth) ⇒ Object
Creates an CardToken object
- parms
-
a hash of parameters; valid keys are:
-
authenticatePayerSet as true to create CardToken for EMV 3DS transaction. [default: false] -
callbackThe URL callback for the cardtoken -
card => addressCityCity of the cardholder. [max length: 50, min length: 2] -
card => addressCountryCountry code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] -
card => addressLine1Address of the cardholder. [max length: 255] -
card => addressLine2Address of the cardholder if needed. [max length: 255] -
card => addressStateState of residence of the cardholder. State abbreviations should be used. [max length: 255] -
card => addressZipPostal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers or letters. [max length: 32] -
card => cvcCVC security code of the card. This is the code on the back of the card. Example: 123 -
card => expMonthExpiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] -
card => expYearExpiration year of the card. Format is YY. Example: 2013 = 13 [min value: 0, max value: 99] -
card => nameName as appears on the card. [max length: 50, min length: 2] -
card => numberCard number as it appears on the card. [max length: 19, min length: 13] -
keyKey used to create the card token. -
secure3DRequestData => amountAmount of the subsequent transaction in the smallest unit of your currency. Example: 100 = $1.00 required -
secure3DRequestData => authOnlySpecifies if the subsequent transaction is going to be a Payment or an Authorization (to be Captured later). If false or not specified, it refers to a Payment, otherwise it refers to an Authorization. -
secure3DRequestData => currencyCurrency code (ISO-4217). Must match the currency associated with your account. required -
secure3DRequestData => descriptionA description of the transaction. [max length: 256] -
secure3DRequestData => id3D Secure data ID. -
sourceCard Token Source [default: API]
- auth
-
Authentication information used for the API call. If no value is passed the global keys Simplify::public_key and Simplify::private_key are used. For backwards compatibility the public and private keys may be passed instead of the authentication object.
Returns a CardToken object.
85 86 87 88 89 90 91 92 93 |
# File 'lib/simplify/cardtoken.rb', line 85 def self.create(parms, *auth) auth_obj = Simplify::PaymentsApi.create_auth_object(auth) h = Simplify::PaymentsApi.execute("cardToken", 'create', parms, auth_obj) obj = CardToken.new() obj.authentication = auth_obj obj = obj.merge!(h) obj end |
.find(id, *auth) ⇒ Object
Retrieve a CardToken object from the API
- id
-
ID of object to retrieve
- auth
-
Authentication information used for the API call. If no value is passed the global keys Simplify::public_key and Simplify::private_key are used. For backwards compatibility the public and private keys may be passed instead of the authentication object.
Returns a CardToken object.
100 101 102 103 104 105 106 107 108 |
# File 'lib/simplify/cardtoken.rb', line 100 def self.find(id, *auth) auth_obj = Simplify::PaymentsApi.create_auth_object(auth) h = Simplify::PaymentsApi.execute("cardToken", 'show', {"id" => id}, auth_obj) obj = CardToken.new() obj.authentication = auth_obj obj = obj.merge!(h) obj end |
Instance Method Details
#private_key ⇒ Object
Returns the private key used when accessing this object. Deprecated: please use ‘authentication’ instead.
50 51 52 |
# File 'lib/simplify/cardtoken.rb', line 50 def private_key return self.authentication.private_key end |
#private_key=(k) ⇒ Object
Sets the private key used when accessing this object. Deprecated: please use ‘authentication’ instead.
55 56 57 |
# File 'lib/simplify/cardtoken.rb', line 55 def private_key=(k) return self.authentication.private_key = k end |
#public_key ⇒ Object
Returns the public key used when accessing this object. Deprecated: please use ‘authentication’ instead.
40 41 42 |
# File 'lib/simplify/cardtoken.rb', line 40 def public_key return self.authentication.public_key end |
#public_key=(k) ⇒ Object
Sets the public key used when accessing this object. Deprecated: please use ‘authentication’ instead.
45 46 47 |
# File 'lib/simplify/cardtoken.rb', line 45 def public_key=(k) return self.authentication.public_key = k end |
#update ⇒ Object
-
device => ipAddressThe IP address of the device used by the payer, in nnn.nnn.nnn.nnn format. (required) -
device => languageThe language supported for the payer’s browser as defined in IETF BCP47. -
device => screenHeightThe total height of the payer’s browser screen in pixels. -
device => screenWidthThe total width of the payer’s browser screen in pixels. -
device => timeZoneThe timezone of the device used by the payer, in Zone ID format. Example: “Europe/Dublin” (required) -
keyThe public key of the merchant to be used for the token
120 121 122 123 124 |
# File 'lib/simplify/cardtoken.rb', line 120 def update() h = Simplify::PaymentsApi.execute("cardToken", 'update', self, self.authentication) self.merge!(h) self end |